============
Installation
============

Python Versions
===============

Tooz is tested under Python 2.7 and 3.4.

.. _install-basic:

Basic Installation
==================

Tooz should be installed into the same site-packages area where
the application and extensions are installed (either a virtualenv or
the global site-packages). You may need administrative privileges to
do that.  The easiest way to install it is using pip_::

  $ pip install tooz

or::

  $ sudo pip install tooz

.. _pip: http://pypi.python.org/pypi/pip

Download
========

Tooz releases are hosted on PyPI and can be downloaded from:
http://pypi.python.org/pypi/tooz

Source Code
===========

The source is hosted on the OpenStack infrastructure: https://git.openstack.org/cgit/openstack/tooz/

Reporting Bugs
==============

Please report bugs through the launchpad project:
https://launchpad.net/python-tooz
